spoon.ber.common

Package spoon :: Package ber :: Module common |
[show private | hide private]
[frames | no frames]

## Module spoon.ber.common

Exceptions
`BERException` |

Function Summary
| ``deflate_long`(n, add_sign_padding)` turns a long-int into a normalized byte string (adapted from Crypto.Util.number)
| ``inflate_long`(s, always_positive)` turns a normalized byte string into a long-int (adapted from Crypto.Util.number)

Variable Summary
`int` | `APPLICATION` = 1
`int` | `CONTEXT` = 2
`int` | `PRIVATE` = 3
`int` | `UNIVERSAL` = 0

Function Details

### deflate_long(n, add_sign_padding=True) turns a long-int into a normalized byte string (adapted from Crypto.Util.number)

### inflate_long(s, always_positive=False) turns a normalized byte string into a long-int (adapted from Crypto.Util.number)

Variable Details

    ### APPLICATION Type: `int` Value:
        1

    ### CONTEXT Type: `int` Value:
        2

    ### PRIVATE Type: `int` Value:
        3

    ### UNIVERSAL Type: `int` Value:
        0

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net